%bcond_with bootstrap

Name:           qdox
Version:        2.1.0
Release:        %mkrel 1
Group:          Development/Java
Summary:        Extract class/interface/method definitions from sources
License:        ASL 2.0
URL:            https://github.com/paul-hammant/qdox
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
Source1:        qdox-MANIFEST.MF
# Remove bundled binaries which are possibly proprietary
Source2:        generate-tarball.sh

BuildRequires:  byaccj
%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  jflex
%endif

%description
QDox is a high speed, small footprint parser
for extracting class/interface/method definitions
from source files complete with JavaDoc @tags.
It is designed to be used by active code
generators or documentation tools.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
API docs for %{name}.

%prep
%setup -q

# remove unnecessary dependency on parent POM
%pom_remove_parent

# We don't need these plugins
%pom_remove_plugin :animal-sniffer-maven-plugin
%pom_remove_plugin :maven-assembly-plugin
%pom_remove_plugin :maven-failsafe-plugin
%pom_remove_plugin :maven-invoker-plugin
%pom_remove_plugin :jflex-maven-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :exec-maven-plugin

%mvn_file : %{name}
%mvn_alias : qdox:qdox

%build
%{?jpb_env}

# Generate scanners (upstream does this with maven-jflex-plugin)
jflex -d src/main/java/com/thoughtworks/qdox/parser/impl src/grammar/lexer.flex
jflex -d src/main/java/com/thoughtworks/qdox/parser/impl src/grammar/commentlexer.flex

# Generate parsers (upstream does this with exec-maven-plugin)
(cd ./src/main/java/com/thoughtworks/qdox/parser/impl
 byaccj -v -Jnorun -Jnoconstruct -Jclass=DefaultJavaCommentParser -Jpackage=com.thoughtworks.qdox.parser.impl ../../../../../../../grammar/commentparser.y
 byaccj -v -Jnorun -Jnoconstruct -Jclass=Parser -Jimplements=CommentHandler -Jsemantic=Value -Jpackage=com.thoughtworks.qdox.parser.impl -Jstack=500 ../../../../../../../grammar/parser.y
)

# Build artifact
%mvn_build -f -- -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

# Inject OSGi manifests
jar ufm target/%{name}-%{version}.jar %{SOURCE1}

%install
%mvn_install

%files -f .mfiles
%license LICENSE.txt
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt


%changelog
* Mon May 27 2024 ns80 <ns80> 2.1.0-1.mga10
+ Revision: 2068219
- new version 2.1.0 for java 21

* Mon Jul 25 2022 neoclust <neoclust> 2.0.0-11.mga9
+ Revision: 1871127
- Disable bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 2.0.0-10.mga9
+ Revision: 1870935
- Add bootstrap build mode
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Sep 06 2020 daviddavid <daviddavid> 0:2.0.0-1.mga8
+ Revision: 1622879
- Update to version 2.0.0
- Remove unnecessary dependency on parent POM
- Rebuilt for JDK-11

* Sun Feb 16 2020 umeabot <umeabot> 0:2.0-3.M9.3.mga8
+ Revision: 1536140
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 0:2.0-3.M9.2.mga8
+ Revision: 1453315
- Port to jflex 1.7.0

* Thu Sep 20 2018 daviddavid <daviddavid> 0:2.0-3.M9.1.mga7
+ Revision: 1288201
- Update to upstream version 2.0-M9 (sync with fc29)
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Update to version 2.0-M8
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 0:2.0-0.4.M3.1.mga6
+ Revision: 978256
- sync package qdox with fedora
+ zezinho <zezinho>
- new version rebased from fedora

* Mon Jan 19 2015 daviddavid <daviddavid> 0:1.12.1-7.mga5
+ Revision: 811469
- Sync with fc21

* Wed Oct 15 2014 umeabot <umeabot> 0:1.12.1-6.mga5
+ Revision: 745610
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0:1.12.1-4.mga4
+ Revision: 532194
- Mageia 4 Mass Rebuild

* Sat Aug 17 2013 dmorgan <dmorgan> 0:1.12.1-3.mga4
+ Revision: 467244
- Fix build with current java stack

* Sun Jan 13 2013 umeabot <umeabot> 0:1.12.1-2.mga3
+ Revision: 379809
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 04 2013 dmorgan <dmorgan> 0:1.12.1-1.mga3
+ Revision: 338757
- New version

* Sun Aug 14 2011 gil <gil> 0:1.12-4.mga2
+ Revision: 133029
- rebuilt with new macro

* Wed Apr 27 2011 dmorgan <dmorgan> 0:1.12-3.mga1
+ Revision: 92143
- Add java_cup as buildrequire
- Remove buildroot
- imported package qdox


* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Oct 5 2010 Alexander Kurtakov <akurtako@redhat.com> 0:1.12-1
- Update to new version.

* Mon Jun 7 2010 Alexander Kurtakov <akurtako@redhat.com> 0:1.11-3
- Make sure to remove all yacc executables.

* Mon Jun 7 2010 Alexander Kurtakov <akurtako@redhat.com> 0:1.11-2
- Symlink byaccj to both yacc.linux and yacc.linux.x86_64 to keep it building as noarch.

* Mon Mar 15 2010 Alexander Kurtakov <akurtako@redhat.com> 0:1.11-1
- Update to 1.11.

* Mon Feb 15 2010 Alexander Kurtakov <akurtako@redhat.com> 0:1.10.1-2
- Rebuild for rhbz#565013.

* Thu Jan 14 2010 Alexander Kurtakov <akurtako@redhat.com> 0:1.10.1-1
- Update to upstream 1.10.1.

* Sat Sep 19 2009 Alexander Kurtakov <akurtako@redhat.com> 0:1.9.2-2
- Remove not needed sources.

* Tue Aug 18 2009 Alexander Kurtakov <akurtako@redhat.com> 0:1.9.2-1
- Update to 1.9.2.

* Fri Apr 03 2009 Ralph Apel <r.apel at r-apel.de> 0:1.8-1.jpp5
- 1.8 as qdox18 because of qdox frozen at 1.6.1 in JPP-5

* Tue Jul 01 2008 Ralph Apel <r.apel at r-apel.de> 0:1.6.3-5.jpp5
- Restore to devel
- Drop mockobjects BR

* Fri Jun 13 2008 Ralph Apel <r.apel at r-apel.de> 0:1.6.3-4.jpp5
- Add com.thoughtworks.qdox groupId to depmap frag

* Tue Feb 26 2008 Ralph Apel <r.apel at r-apel.de> 0:1.6.3-3jpp
- Add settings file
- Fix pom marking jmock dependency as of scope test
- Fix -jpp-depmap.xml for asm2-parent

* Mon Nov 26 2007 Ralph Apel <r.apel at r-apel.de> 0:1.6.3-2jpp
- Fix maven macro value

* Thu Nov 22 2007 Ralph Apel <r.apel at r-apel.de> 0:1.6.3-1jpp
- Upgrade to 1.6.3

* Wed May 30 2007 Ralph Apel <r.apel at r-apel.de> 0:1.6.2-1jpp
- Upgrade to 1.6.2
- Activate tests while building with ant
- Make Vendor, Distribution based on macro
- Install depmap frags, poms

* Thu Mar 22 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:1.6.1-1jpp.ep1.4
- Rebuild with fixed component-info.xml

* Fri Feb 23 2007 Ralph Apel <r.apel at r-apel.de> 0:1.5-3jpp
- Add option to build without maven
- Omit tests when building without maven
- Add gcj_support option

* Mon Feb 20 2006 Ralph Apel <r.apel at r-apel.de> - 0:1.5-2jpp
- Rebuild for JPP-1.7, adapting to maven-1.1

* Wed Nov 16 2005 Ralph Apel <r.apel at r-apel.de> - 0:1.5-1jpp
- Upgrade to 1.5
- Build is now done with maven and requires jflex and byaccj

* Wed Aug 25 2004 Fernando Nasser <fnasser@redhat.com> - 0:1.4-3jpp
- Rebuild with Ant 1.6.2

* Fri Aug 06 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.4-2jpp
- Upgrade to ant-1.6.X

* Mon Jun 07 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.4-1jpp
- Upgrade to 1.4
- Drop Requires: mockobjects (Build/Test only)

* Tue Feb 24 2004 Ralph Apel <r.apel at r-apel.de> - 0:1.3-1jpp
- First JPackage release
